"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const aws_sdk_1 = __importDefault(require("aws-sdk"));
const createTaskDefinition_1 = require("./createTaskDefinition");
const eventbridge = new aws_sdk_1.default.EventBridge({ apiVersion: '2015-10-07', region: 'eu-west-1' });
function createCronEvent(opts, name, env) {
    return new Promise(async (resolve, reject) => {
        const params = {
            Name: opts[env].cronName || `${name}-cron`,
            // cron's initial value is null but this property accepts undefined
            ScheduleExpression: opts[env].cron || undefined,
            State: "ENABLED"
        };
        eventbridge.putRule(params, (err, res) => {
            if (err)
                reject(err);
            else
                resolve(res);
        });
    });
}
function updateCronEvent(opts, name, env) {
    return new Promise(async (resolve, reject) => {
        var _a;
        const taskFamily = `${opts.stack}-${opts.type}-${env}-${name}`;
        const latestTaskDef = await (0, createTaskDefinition_1.describeTaskDef)(taskFamily, opts[env].region);
        const taskRevision = (_a = latestTaskDef.taskDefinition) === null || _a === void 0 ? void 0 : _a.revision;
        const cluster = env === 'live' ? `${opts.stack}-${opts.type}` : `${opts.stack}-${opts.type}-${env}`;
        const params = {
            Rule: opts[env].cronName || `${name}-cron`,
            Targets: [
                {
                    Id: opts[env].cronName || `${name}-cron`,
                    Arn: `arn:aws:ecs:${opts[env].region}:${opts[env].aws}:cluster/${cluster}`,
                    RoleArn: `arn:aws:iam::${opts[env].aws}:role/ecsEventsRole`,
                    EcsParameters: {
                        TaskDefinitionArn: `arn:aws:ecs:${opts[env].region}:${opts[env].aws}:task-definition/${taskFamily}:${taskRevision}`,
                        TaskCount: opts[env].desiredCount,
                        LaunchType: "FARGATE",
                        PlatformVersion: "LATEST",
                        NetworkConfiguration: {
                            awsvpcConfiguration: {
                                Subnets: ["subnet-d1e59d88", "subnet-b8a59ddd", "subnet-bb1e3ecc"],
                                SecurityGroups: ["sg-0867b0942f4dd8798"],
                                AssignPublicIp: "ENABLED"
                            }
                        }
                    }
                }
            ]
        };
        eventbridge.putTargets(params, (err, res) => {
            if (err) {
                console.log(`failed puting targets ${err}`);
                reject(err);
            }
            else {
                resolve(res);
            }
            ;
        });
    });
}
async function updateCron(opts, name, env) {
    // can we update the service?
    try {
        const res = await updateCronEvent(opts, name, env);
        console.log('cron updated');
    }
    catch (e) {
        console.log(`error updating cron ${e}`);
        if (e.statusCode === 400) {
            console.log('cron not found, trying to create it...');
        }
        else {
            return e;
        }
    }
    try {
        await createCronEvent(opts, name, env);
        console.log('cron created');
    }
    catch (e) {
        console.log(e);
        return e;
    }
}
exports.default = updateCron;
//# sourceMappingURL=updateCron.js.map