"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const aws_sdk_1 = __importDefault(require("aws-sdk"));
const createTaskDefinition_1 = require("./createTaskDefinition");
function createService(opts, name, env) {
    return new Promise((resolve, reject) => {
        const ecs = new aws_sdk_1.default.ECS({
            apiVersion: '2014-11-13',
            region: opts[env].region,
        });
        const params = {
            cluster: env === 'live' ? `${opts.stack}-${opts.type}` : `${opts.stack}-${opts.type}-${env}`,
            serviceName: `${name}-${env}`,
            taskDefinition: `${opts.stack}-${opts.type}-${env}-${name}`,
            desiredCount: opts[env].desiredCount,
            launchType: 'FARGATE',
            networkConfiguration: {
                awsvpcConfiguration: {
                    subnets: opts[env].subnets,
                    assignPublicIp: 'DISABLED',
                },
            },
        };
        ecs.createService(params, (err, res) => {
            if (err)
                reject(err);
            else
                resolve(res);
        });
    });
}
function updateService(opts, name, env) {
    return new Promise(async (resolve, reject) => {
        var _a;
        const ecs = new aws_sdk_1.default.ECS({
            apiVersion: '2014-11-13',
            region: opts[env].region,
        });
        const taskFamily = `${opts.stack}-${opts.type}-${env}-${name}`;
        const latestTaskDef = await (0, createTaskDefinition_1.describeTaskDef)(taskFamily, opts[env].region);
        const taskRevision = (_a = latestTaskDef.taskDefinition) === null || _a === void 0 ? void 0 : _a.revision;
        const params = {
            cluster: env === 'live' ? `${opts.stack}-${opts.type}` : `${opts.stack}-${opts.type}-${env}`,
            service: `${name}-${env}`,
            desiredCount: opts[env].desiredCount,
            taskDefinition: `${taskFamily}:${taskRevision}`,
            forceNewDeployment: true,
        };
        ecs.updateService(params, (err, res) => {
            if (err)
                reject(err);
            else
                resolve(res);
        });
    });
}
async function updateECSService(opts, name, env) {
    // can we update the service?
    try {
        const res = await updateService(opts, name, env);
        console.log('Service updated');
        return res;
    }
    catch (e) {
        if (e.statusCode === 400) {
            console.log('Service not found, trying to create it...');
        }
        else {
            return e;
        }
    }
    try {
        await createService(opts, name, env);
        console.log('Service created');
        return 'created';
    }
    catch (e) {
        console.log(e);
        return e;
    }
}
exports.default = updateECSService;
//# sourceMappingURL=updateECSService.js.map